Struct AssertionFailure

pub struct AssertionFailure<'r, T: 'r> { /* private fields */ }
A failed assertion.

This exposes builder methods to construct the final failure message.

Implementations

Source

impl<'r, T: DescriptiveSpec<'r>> AssertionFailure<'r, T>

pub fn from_spec(spec: &'r T) -> AssertionFailure<'r, T>

Construct a new AssertionFailure from a DescriptiveSpec.

pub fn with_expected(&mut self, expected: String) -> &mut Self

Builder method to add the expected value for the panic message.

pub fn with_actual(&mut self, actual: String) -> &mut Self

Builder method to add the actual value for the panic message.

pub fn fail(&mut self)

Builds the failure message with a description (if present), the expected value, and the actual value and then calls panic with the created message.